@@ -86,7 +86,7 @@
 #define KGLOBALACCEL_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KGLOBALACCEL_NO_DEPRECATED
-#  define KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
+#  define KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
 #endif
 #ifdef KGLOBALACCEL_NO_DEPRECATED_WARNINGS
 #  define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0x55d00
+#    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0x55e00
 #  endif
 #endif
 
@@ -199,7 +199,7 @@
 #define KGLOBALACCEL_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KGLOBALACCEL_NO_DEPRECATED
-#  define KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
+#  define KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
 #endif
 #ifdef KGLOBALACCEL_NO_DEPRECATED_WARNINGS
 #  define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0
@@ -209,7 +209,7 @@
 #  ifdef KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0x55d00
+#    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0x55e00
 #  endif
 #endif
 
